@@ -255,28 +255,46 @@ void importCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self )
 	}
 	if (stampChksum==calcChksum||stampChksum==911) {
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) CHECKSUM is GOOD!!! ready to read and import command data!", self);
-		gchar *title = g_key_file_get_string (keyFile, "queen-beecon-exported-command", "title", NULL);
+		gchar *title = g_strdup(g_key_file_get_string (keyFile, "queen-beecon-exported-command", "title", NULL));
 		gchar *command = g_key_file_get_string (keyFile, "queen-beecon-exported-command", "command", NULL);
 		g_key_file_free (keyFile);
 
+		gboolean uniqueCommand; gint i;
+		do {
+			uniqueCommand=TRUE;
+			for(i=0;i<self->priv->c_size;i++) {
+				qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) Testing unicity command title [%s] vs. [%s]", self, title, self->priv->c_titles[i]);
+				if (!g_strcmp0(title, self->priv->c_titles[i])) {
+					qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) MATCH!!!", self);
+					uniqueCommand=FALSE;
+					break;
+				}
+			}
+			if (!uniqueCommand) {
+				gchar *auxCmd = g_strconcat(title, "+", NULL);
+				qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) Generating new title [%s]", self, auxCmd);
+				g_free(title);
+				title=auxCmd;
+			}
+		} while (!uniqueCommand);
+
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) About to call AddCommand title=[%s] command=[%s]", self, title, command);
-		AddCommand(self, g_strdup(title), g_strdup(command), FALSE);
+		AddCommand(self, title, g_strdup(command), FALSE);
 
 		//g_mutex_lock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
 		queen_beecon_write_settings (self, FALSE); // We write commands to config file
 		//g_mutex_unlock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
 
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command selector adding new command", self);
-		GtkWidget *commandPickerSelector = hildon_touch_selector_new_text ();
-		gint i;
+		hildon_picker_button_set_active(HILDON_PICKER_BUTTON (self->priv->commandPicker), -1);
+		hildon_touch_selector_set_active (hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), 0, -1);
+		gtk_list_store_clear(GTK_LIST_STORE(hildon_touch_selector_get_model(hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), 0)));
 		for(i=0;i<self->priv->c_size;i++) {
 			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Append Command [%d] [%s]", self, i, self->priv->c_titles[i]);
-			hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (commandPickerSelector), self->priv->c_titles[i]);
+			hildon_touch_selector_append_text (hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), self->priv->c_titles[i]);
 		}
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command to selector [%p] set active %d", self, commandPickerSelector, self->priv->c_size-1);
-		hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (commandPickerSelector), 0, self->priv->c_size-1);
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command selector set selector [%p] to picker [%p]", self, commandPickerSelector, self->priv->commandPicker);
-		hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (self->priv->commandPicker), HILDON_TOUCH_SELECTOR (commandPickerSelector));
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command to picker [%p] set active %d", self, self->priv->commandPicker, self->priv->c_size-1);
+		hildon_touch_selector_set_active (hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), 0, self->priv->c_size-1);
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command to picker [%p] set active %d", self, self->priv->commandPicker, self->priv->c_size-1);
 		hildon_picker_button_set_active (HILDON_PICKER_BUTTON (self->priv->commandPicker), self->priv->c_size-1);
 
@@ -285,7 +303,7 @@ void importCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self )
 		gtk_text_buffer_set_text(self->priv->cmdTestDriveBuffer,c,-1);
 		g_free(c);
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Command successfully added to Command List and to Test Drive command input.", self);
-		hildon_banner_show_informationf (NULL, NULL, "SUCCESS! Command added to Command List and to Test Drive command input.");
+		hildon_banner_show_informationf (NULL, NULL, "SUCCESS! Command added to Command List and to Test Drive command input as [%s]", title);
 		//GtkWidget *info = hildon_note_new_information (NULL, "SUCCESS! Command added to Command List and to Test Drive command input.");gtk_dialog_run (GTK_DIALOG (info));gtk_object_destroy (GTK_OBJECT (info));
 	} else {
 		hildon_banner_show_informationf (NULL, NULL, "WARNING! Bad Checksum!\nPossibly corrupt Import Command Data!");
@@ -425,6 +443,25 @@ void importInstanceBt_clicked_cb ( HildonButton *button, QueenBeecon *self )
 		//g_mutex_lock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
 		queen_beecon_read_settings ( self, TRUE, TRUE, c);
 
+		gboolean uniqueCommand; gint i;
+		do {
+			uniqueCommand=TRUE;
+			for(i=0;i<self->priv->c_size;i++) {
+				qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) Testing unicity command title [%s] vs. [%s]", self, self->priv->instanceTitle, self->priv->c_titles[i]);
+				if (!g_strcmp0(self->priv->instanceTitle, self->priv->c_titles[i])) {
+					qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) MATCH!!!", self);
+					uniqueCommand=FALSE;
+					break;
+				}
+			}
+			if (!uniqueCommand) {
+				gchar *auxCmd = g_strconcat(self->priv->instanceTitle, "+", NULL);
+				qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) Generating new title [%s]", self, auxCmd);
+				g_free(self->priv->instanceTitle);
+				self->priv->instanceTitle=auxCmd;
+			}
+		} while (!uniqueCommand);
+
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) AddCommand title=[%s] command=[%s]", self, self->priv->instanceTitle, self->priv->instanceCmd);
 		AddCommand(self, g_strdup(self->priv->instanceTitle), g_strdup(self->priv->instanceCmd), TRUE);
 
@@ -432,21 +469,21 @@ void importInstanceBt_clicked_cb ( HildonButton *button, QueenBeecon *self )
 		//g_mutex_unlock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
 
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command selector adding new command", self);
-		GtkWidget *commandPickerSelector = hildon_touch_selector_new_text ();
-		gint i;
+		hildon_picker_button_set_active(HILDON_PICKER_BUTTON (self->priv->commandPicker), -1);
+		hildon_touch_selector_set_active (hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), 0, -1);
+		gtk_list_store_clear(GTK_LIST_STORE(hildon_touch_selector_get_model(hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), 0)));
+
 		for(i=0;i<self->priv->c_size;i++) {
 			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Append Command [%d] [%s]", self, i, self->priv->c_titles[i]);
-			hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (commandPickerSelector), self->priv->c_titles[i]);
+			hildon_touch_selector_append_text (hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), self->priv->c_titles[i]);
 		}
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command to selector [%p] set active %d", self, commandPickerSelector, self->priv->c_size-1);
-		hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (commandPickerSelector), 0, self->priv->c_size-1);
-
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command selector set selector [%p] to picker [%p]", self, commandPickerSelector, self->priv->commandPicker);
-		hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (self->priv->commandPicker), HILDON_TOUCH_SELECTOR (commandPickerSelector));
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command to picker [%p] set active %d", self, self->priv->commandPicker, self->priv->c_size-1);
+		hildon_touch_selector_set_active (hildon_picker_button_get_selector(HILDON_PICKER_BUTTON (self->priv->commandPicker)), 0, self->priv->c_size-1);
 
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Rebuilding command to picker [%p] set active %d", self, self->priv->commandPicker, self->priv->c_size-1);
 		hildon_picker_button_set_active (HILDON_PICKER_BUTTON (self->priv->commandPicker), self->priv->c_size-1);
-		hildon_banner_show_informationf (NULL, NULL, "SUCCESS! Instance imported into current Beecon/Snippet!\nCommand added to command list.");
+
+		hildon_banner_show_informationf (NULL, NULL, "SUCCESS! Instance imported into current Beecon/Snippet!\nCommand added to command list as [%s]", self->priv->instanceTitle);
 		//GtkWidget *info = hildon_note_new_information (NULL, "SUCCESS! Instance imported into current Beecon/Snippet!\nCommand added to command list.");gtk_dialog_run (GTK_DIALOG (info));gtk_object_destroy (GTK_OBJECT (info));
 		self->priv->instanceImportOK=TRUE;
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Instance Settings loaded successfully", self);
