@@ -78,7 +78,6 @@ void queen_beecon_async_sync_exec_out(QueenBeecon *self, const gchar *whoareyou)
      	}
     	gtk_label_set_markup (GTK_LABEL (self->priv->cmdResult_lb), self->priv->execAuxOutput);//AP
 
-//    	if (g_strcmp0(gtk_label_get_label (GTK_LABEL(self->priv->cmdResult_lb)), self->priv->execAuxOutput)) {
         PangoAttrList *attrs;
         gchar *text;
         if (!pango_parse_markup (self->priv->execAuxOutput, -1, 0, &attrs, &text, NULL, NULL) ) {
@@ -260,9 +259,15 @@ gchar *queen_beecon_g_command_param_subst(QueenBeecon *self, const gchar *cmd, c
 	r = g_strreplace(x,"$QBW_CLICK_X",               b); g_free(b); b = NULL; g_free(x); x = r;
 	b = g_strdup_printf("%d", self->priv->clickY);
 	r = g_strreplace(x,"$QBW_CLICK_Y",               b); g_free(b); b = NULL; g_free(x); x = r;
+	b = g_strdup_printf("%d", (gint)self->priv->widWidth);
+	r = g_strreplace(x,"$QBW_WIDTH",                 b); g_free(b); b = NULL; g_free(x); x = r;
+	b = g_strdup_printf("%d", (gint)self->priv->widHeight);
+	r = g_strreplace(x,"$QBW_HEIGHT",                b); g_free(b); b = NULL; g_free(x); x = r;
 	b = g_strdup_printf("%d", self->priv->clicksCount);
 	r = g_strreplace(x,"$QBW_CLICKS_COUNT",          b); g_free(b); b = NULL; g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_CURRENT_RESULTS_TEXT",  gtk_label_get_label(GTK_LABEL (self->priv->cmdResult_lb))); g_free(x); x = r;
+	b = g_strdup_printf("%d", self->priv->cmdExitStatus);
+	r = g_strreplace(x,"$QBW_PREVIOUS_EXIT_STATUS",  b); g_free(b); b = NULL; g_free(x); x = r;
     r = g_strreplace(x,"$QBW_HTTP_PROXY",            self->priv->qbwHttpProxy       ? self->priv->qbwHttpProxy       :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_HTTPS_PROXY",           self->priv->qbwHttpsProxy      ? self->priv->qbwHttpsProxy      :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_IGNORE_HOSTS_PROXY",    self->priv->qbwIgnoreHosts     ? self->priv->qbwIgnoreHosts     :""); g_free(x); x = r;
