@@ -93,6 +93,7 @@ GType queen_beecon_get_type (void);
 #define NETWORK__UNRELATED 0
 #define NETWORK__ONLY_CONNECTED 1
 #define NETWORK__ONLY_DISCONNECTED 2
+#define NETWORK__PASSTHROUGH 3
 
 #define SIZE_WIDTH_ALL 800
 #define SIZE_HEIGHT_ALL 420//AP3
@@ -146,8 +147,8 @@ gboolean queen_beecon_edit_add_dialog ( QueenBeecon *self, gboolean new, gint cu
 void queen_beecon_settings (HDHomePluginItem *hitem, QueenBeecon *self);
 
 //Auxiliary functions' prototypes:
-void AddCommand(QueenBeecon *self, gchar * s_title, gchar * s_command, gboolean doInstantiate);
-void EditCommand(QueenBeecon *self, gchar * s_title, gchar * s_command, gboolean doInstantiate, int index);
+gboolean AddCommand(QueenBeecon *self, gchar * s_title, gchar * s_command, gboolean doInstantiate);
+gboolean EditCommand(QueenBeecon *self, gchar * s_title, gchar * s_command, gboolean doInstantiate, int index);
 void DelCommand(QueenBeecon *self, int index);
 guint GetSeconds(guint index);
 
@@ -342,8 +343,8 @@ struct _QueenBeeconPrivate
 		GtkWidget *advancedDialog;
 
 		// Widgets in Settings Dialog
-		GtkWidget *selectorW;
-		GtkWidget *cmdSelectorW;
+		GtkWidget *cmdTouchSelectorW;
+		GtkWidget *cmdPickerButtonW;
 		GtkWidget *dialogW;
 		GtkWidget *settingsAreaW;
 		GtkWidget *scrollW;
